@@ -5,15 +5,15 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- */ 
+ */
 
 
 package org.apache.commons.beanutils;
@@ -39,8 +39,7 @@ import junit.framework.TestSuite;
  * These tests were based on the ones in <code>PropertyUtilsTestCase</code>
  * because the two classes provide similar levels of functionality.</p>
  *
- * @author Craig R. McClanahan
- * @version $Revision: 745090 $ $Date: 2009-02-17 14:12:41 +0000 (Tue, 17 Feb 2009) $
+ * @version $Id: BasicDynaBeanTestCase.java 1479595 2013-05-06 14:59:37Z sebb $
  */
 
 public class BasicDynaBeanTestCase extends TestCase {
@@ -101,6 +100,7 @@ public class BasicDynaBeanTestCase extends TestCase {
     /**
      * Set up instance variables required by this test case.
      */
+    @Override
     public void setUp() throws Exception {
 
         // Instantiate a new DynaBean instance
@@ -117,7 +117,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         int intIndexed[] = { 0, 10, 20, 30, 40 };
         bean.set("intIndexed", intIndexed);
         bean.set("intProperty", new Integer(123));
-        List listIndexed = new ArrayList();
+        List<String> listIndexed = new ArrayList<String>();
         listIndexed.add("String 0");
         listIndexed.add("String 1");
         listIndexed.add("String 2");
@@ -125,11 +125,11 @@ public class BasicDynaBeanTestCase extends TestCase {
         listIndexed.add("String 4");
         bean.set("listIndexed", listIndexed);
         bean.set("longProperty", new Long(321));
-        HashMap mappedProperty = new HashMap();
+        HashMap<String, String> mappedProperty = new HashMap<String, String>();
         mappedProperty.put("First Key", "First Value");
         mappedProperty.put("Second Key", "Second Value");
         bean.set("mappedProperty", mappedProperty);
-        HashMap mappedIntProperty = new HashMap();
+        HashMap<String, Integer> mappedIntProperty = new HashMap<String, Integer>();
         mappedIntProperty.put("One", new Integer(1));
         mappedIntProperty.put("Two", new Integer(2));
         bean.set("mappedIntProperty", mappedIntProperty);
@@ -159,6 +159,7 @@ public class BasicDynaBeanTestCase extends TestCase {
     /**
      * Tear down instance variables required by this test case.
      */
+    @Override
     public void tearDown() {
 
         bean = null;
@@ -1013,7 +1014,7 @@ public class BasicDynaBeanTestCase extends TestCase {
      * @param name Name of the property to be retrieved
      * @param type Expected class type of this property
      */
-    protected void testGetDescriptorBase(String name, Class type) {
+    protected void testGetDescriptorBase(String name, Class<?> type) {
 
         try {
             DynaProperty descriptor =
