@@ -5,15 +5,15 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- */ 
+ */
 
 
 package org.apache.commons.beanutils;
@@ -46,8 +46,7 @@ import java.util.Map;
  * <p>Mock object that implements enough of <code>java.sql.ResultSet</code>
  * to exercise the {@link ResultSetDynaClass} functionality.</p>
  *
- * @author Craig R. McClanahan
- * @version $Revision: 745080 $ $Date: 2009-02-17 14:05:02 +0000 (Tue, 17 Feb 2009) $
+ * @version $Id: TestResultSet.java 1540186 2013-11-08 21:08:30Z oheger $
  */
 
 public class TestResultSet implements InvocationHandler {
@@ -89,17 +88,17 @@ public class TestResultSet implements InvocationHandler {
      */
     public static ResultSet createProxy(InvocationHandler invocationHandler) {
         ClassLoader classLoader = ResultSet.class.getClassLoader();
-        Class[] interfaces = new Class[] { ResultSet.class };
+        Class<?>[] interfaces = new Class[] { ResultSet.class };
         return (ResultSet)Proxy.newProxyInstance(classLoader, interfaces, invocationHandler);
     }
-    
+
     /**
      * Create a proxy ResultSet.
      */
     public TestResultSet() {
         this(TestResultSetMetaData.createProxy());
     }
-    
+
     /**
      * Create a proxy ResultSet with the specified meta data.
      *
@@ -110,7 +109,7 @@ public class TestResultSet implements InvocationHandler {
     }
 
     /**
-     * Handles method invocation on the ResultSet proxy. 
+     * Handles method invocation on the ResultSet proxy.
      *
      * @param proxy The proxy ResultSet object
      * @param method the method being invoked
@@ -138,7 +137,7 @@ public class TestResultSet implements InvocationHandler {
             updateObject((String)args[0], args[1]);
             return null;
         }
-        
+
         throw new UnsupportedOperationException(methodName + " not implemented");
     }
 
@@ -300,6 +299,7 @@ public class TestResultSet implements InvocationHandler {
     }
 
     /** @deprecated */
+    @Deprecated
     public BigDecimal getBigDecimal(int columnIndex, int scale)
         throws SQLException {
         throw new UnsupportedOperationException();
@@ -312,6 +312,7 @@ public class TestResultSet implements InvocationHandler {
 
 
     /** @deprecated */
+    @Deprecated
     public BigDecimal getBigDecimal(String columnName, int scale)
         throws SQLException {
         throw new UnsupportedOperationException();
@@ -471,12 +472,12 @@ public class TestResultSet implements InvocationHandler {
     }
 
 
-    public Object getObject(int columnIndex, Map map) throws SQLException {
+    public Object getObject(int columnIndex, Map<?, ?> map) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
 
-    public Object getObject(String columnName, Map map) throws SQLException {
+    public Object getObject(String columnName, Map<?, ?> map) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
@@ -561,12 +562,14 @@ public class TestResultSet implements InvocationHandler {
 
 
     /** @deprecated */
+    @Deprecated
     public InputStream getUnicodeStream(int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
 
     /** @deprecated */
+    @Deprecated
     public InputStream getUnicodeStream(String columnName) throws SQLException {
         throw new UnsupportedOperationException();
     }
