@@ -5,15 +5,15 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- */ 
+ */
 
 package org.apache.commons.beanutils.locale;
 
@@ -25,9 +25,10 @@ import java.text.DecimalFormat;
 import java.text.NumberFormat;
 import java.util.Locale;
 
-import junit.framework.TestCase;
 import junit.framework.Test;
+import junit.framework.TestCase;
 import junit.framework.TestSuite;
+
 import org.apache.commons.beanutils.ConversionException;
 
 
@@ -37,9 +38,7 @@ import org.apache.commons.beanutils.ConversionException;
  *  See unimplemented functionality of the convert utils in the method begining with fixme
  * </p>
  *
- * @author  Michael Szlapa
- * @author Paul Hamamnt & Rune Johannesen (pairing) - patches.
- * @version $Revision: 628158 $ $Date: 2008-02-15 20:14:20 +0000 (Fri, 15 Feb 2008) $
+ * @version $Id: LocaleConvertUtilsTestCase.java 1540186 2013-11-08 21:08:30Z oheger $
  */
 
 public class LocaleConvertUtilsTestCase extends TestCase {
@@ -67,6 +66,7 @@ public class LocaleConvertUtilsTestCase extends TestCase {
     /**
      * Set up instance variables required by this test case.
      */
+    @Override
     public void setUp() {
 
         LocaleConvertUtils.deregister();
@@ -92,6 +92,7 @@ public class LocaleConvertUtilsTestCase extends TestCase {
     /**
      * Tear down instance variables required by this test case.
      */
+    @Override
     public void tearDown() {
         // No action required
     }
@@ -134,8 +135,6 @@ public class LocaleConvertUtilsTestCase extends TestCase {
      */
     public void testNegativeScalar() {
 
-        Object value = null;
-
         /*  fixme Boolean converters not implemented at this point
         value = LocaleConvertUtils.convert("foo", Boolean.TYPE);
         ...
@@ -146,14 +145,14 @@ public class LocaleConvertUtilsTestCase extends TestCase {
 
 
         try {
-            value = LocaleConvertUtils.convert("foo", Byte.TYPE);
+            LocaleConvertUtils.convert("foo", Byte.TYPE);
             fail("Should have thrown conversion exception (1)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Byte.class);
+            LocaleConvertUtils.convert("foo", Byte.class);
             fail("Should have thrown conversion exception (2)");
         } catch (ConversionException e) {
             // Expected result
@@ -169,70 +168,70 @@ public class LocaleConvertUtilsTestCase extends TestCase {
          */
 
         try {
-            value = LocaleConvertUtils.convert("foo", Double.TYPE);
+            LocaleConvertUtils.convert("foo", Double.TYPE);
             fail("Should have thrown conversion exception (3)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Double.class);
+            LocaleConvertUtils.convert("foo", Double.class);
             fail("Should have thrown conversion exception (4)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Float.TYPE);
+            LocaleConvertUtils.convert("foo", Float.TYPE);
             fail("Should have thrown conversion exception (5)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Float.class);
+            LocaleConvertUtils.convert("foo", Float.class);
             fail("Should have thrown conversion exception (6)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Integer.TYPE);
+            LocaleConvertUtils.convert("foo", Integer.TYPE);
             fail("Should have thrown conversion exception (7)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Integer.class);
+            LocaleConvertUtils.convert("foo", Integer.class);
             fail("Should have thrown conversion exception (8)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Byte.TYPE);
+            LocaleConvertUtils.convert("foo", Byte.TYPE);
             fail("Should have thrown conversion exception (9)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Long.class);
+            LocaleConvertUtils.convert("foo", Long.class);
             fail("Should have thrown conversion exception (10)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Short.TYPE);
+            LocaleConvertUtils.convert("foo", Short.TYPE);
             fail("Should have thrown conversion exception (11)");
         } catch (ConversionException e) {
             // Expected result
         }
 
         try {
-            value = LocaleConvertUtils.convert("foo", Short.class);
+            LocaleConvertUtils.convert("foo", Short.class);
             fail("Should have thrown conversion exception (12)");
         } catch (ConversionException e) {
             // Expected result
@@ -629,6 +628,17 @@ public class LocaleConvertUtilsTestCase extends TestCase {
         assertEquals("Integer Array Value", new Integer(123), ((Integer[])result)[0]);
     }
 
+    /**
+     * Tests a conversion if there is no suitable converter registered. In this
+     * case, the string converter is used, and the passed in target type is
+     * ignored. (This test is added to prevent a regression after the locale
+     * converters have been generified.)
+     */
+    public void testDefaultToStringConversionUnsupportedType() {
+        Integer value = 20131101;
+        assertEquals("Wrong result", value.toString(),
+                LocaleConvertUtils.convert(value.toString(), getClass()));
+    }
 
     // -------------------------------------------------------- Private Methods
 
